==> ejc-zjkjcost-api-3.0.0-20220622.074609-6-sources.jar: com/ejianc/business/zjkjcost/finish/vo/ApproveVO.java <==
package com.ejianc.business.zjkjcost.finish.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 竣工考核-目标责任书竣工兑现审批-主表
 * 
 * @author generator
 * 
 */
@ApiModel("竣工考核-目标责任书竣工兑现审批-主表")
public class ApproveVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("单据编号")
    private String billCode;
    @ApiModelProperty("申报主表id")
    private Long applyId;
    @ApiModelProperty("申报主表code")
    private Long applyCode;
    @ApiModelProperty("合同主键")
    private Long contractId;
    @ApiModelProperty("合同名称")
    private String contractName;
    @ApiModelProperty("合同code")
    private String contractCode;
    @ApiModelProperty("项目")
    private Long projectId;
    @ApiModelProperty("项目名称")
    private String projectName;
    @ApiModelProperty("项目code")
    private String projectCode;
    @ApiModelProperty("经办人")
    private Long employeeId;
    @ApiModelProperty("经办人名称")
    private String employeeName;
    @ApiModelProperty("经办部门")
    private Long departmentId;
    @ApiModelProperty("经办部门名称")
    private String departmentName;
    @ApiModelProperty("组织")
    private Long orgId;
    @ApiModelProperty("组织名称")
    private String orgName;
    @ApiModelProperty("组织code")
    private String orgCode;
    @ApiModelProperty("父级组织名称")
    private String parentOrgName;
    @ApiModelProperty("父级组织编码")
    private String parentOrgCode;
    @ApiModelProperty("父级组织")
    private Long parentOrgId;
    @ApiModelProperty("依据")
    private String accord;
    @ApiModelProperty("所属单位商务管理部意见兑现金额")
    private BigDecimal departmentCashMny;
    @ApiModelProperty("所属单位财务资金部扣款金额")
    private BigDecimal capitalDeductMny;
    @ApiModelProperty("所属单位建造管理部扣款金额")
    private BigDecimal buildDeductMny;
    @ApiModelProperty("所属单位工程技术中心扣款金额")
    private BigDecimal technologyDeductMny;
    @ApiModelProperty("所属单位设计中心扣款金额")
    private BigDecimal designDeductMny;
    @ApiModelProperty("所属单位分管领导审核兑现金额")
    private BigDecimal leaderCashMny;
    @ApiModelProperty(" 所属单位总经理审批兑现金额")
    private BigDecimal managerCashMny;
    @ApiModelProperty("所属单位董事长审批兑现金额")
    private BigDecimal chairmanCashMny;
    

    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 申报主表id
     */
    public Long getApplyId() {
        return applyId;
    }

    /**
     * 申报主表id
     */
    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    /**
     * 申报主表code
     */
    public Long getApplyCode() {
        return applyCode;
    }

    /**
     * 申报主表code
     */
    public void setApplyCode(Long applyCode) {
        this.applyCode = applyCode;
    }
    /**
     * 合同主键
     */
    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同code
     */
    public String getContractCode() {
        return contractCode;
    }

    /**
     * 合同code
     */
    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 项目
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目code
     */
    public String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目code
     */
    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 经办人
     */
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 经办部门
     */
    public Long getDepartmentId() {
        return departmentId;
    }

    /**
     * 经办部门
     */
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    /**
     * 经办部门名称
     */
    public String getDepartmentName() {
        return departmentName;
    }

    /**
     * 经办部门名称
     */
    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 组织code
     */
    public String getOrgCode() {
        return orgCode;
    }

    /**
     * 组织code
     */
    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    /**
     * 父级组织名称
     */
    public String getParentOrgName() {
        return parentOrgName;
    }

    /**
     * 父级组织名称
     */
    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    /**
     * 父级组织编码
     */
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    /**
     * 父级组织编码
     */
    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    /**
     * 父级组织
     */
    public Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 父级组织
     */
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 依据
     */
    public String getAccord() {
        return accord;
    }

    /**
     * 依据
     */
    public void setAccord(String accord) {
        this.accord = accord;
    }
    /**
     * 所属单位商务管理部意见兑现金额
     */
    public BigDecimal getDepartmentCashMny() {
        return departmentCashMny;
    }

    /**
     * 所属单位商务管理部意见兑现金额
     */
    public void setDepartmentCashMny(BigDecimal departmentCashMny) {
        this.departmentCashMny = departmentCashMny;
    }
    /**
     * 所属单位财务资金部扣款金额
     */
    public BigDecimal getCapitalDeductMny() {
        return capitalDeductMny;
    }

    /**
     * 所属单位财务资金部扣款金额
     */
    public void setCapitalDeductMny(BigDecimal capitalDeductMny) {
        this.capitalDeductMny = capitalDeductMny;
    }
    /**
     * 所属单位建造管理部扣款金额
     */
    public BigDecimal getBuildDeductMny() {
        return buildDeductMny;
    }

    /**
     * 所属单位建造管理部扣款金额
     */
    public void setBuildDeductMny(BigDecimal buildDeductMny) {
        this.buildDeductMny = buildDeductMny;
    }
    /**
     * 所属单位工程技术中心扣款金额
     */
    public BigDecimal getTechnologyDeductMny() {
        return technologyDeductMny;
    }

    /**
     * 所属单位工程技术中心扣款金额
     */
    public void setTechnologyDeductMny(BigDecimal technologyDeductMny) {
        this.technologyDeductMny = technologyDeductMny;
    }
    /**
     * 所属单位设计中心扣款金额
     */
    public BigDecimal getDesignDeductMny() {
        return designDeductMny;
    }

    /**
     * 所属单位设计中心扣款金额
     */
    public void setDesignDeductMny(BigDecimal designDeductMny) {
        this.designDeductMny = designDeductMny;
    }
    /**
     * 所属单位分管领导审核兑现金额
     */
    public BigDecimal getLeaderCashMny() {
        return leaderCashMny;
    }

    /**
     * 所属单位分管领导审核兑现金额
     */
    public void setLeaderCashMny(BigDecimal leaderCashMny) {
        this.leaderCashMny = leaderCashMny;
    }
    /**
     *  所属单位总经理审批兑现金额
     */
    public BigDecimal getManagerCashMny() {
        return managerCashMny;
    }

    /**
     *  所属单位总经理审批兑现金额
     */
    public void setManagerCashMny(BigDecimal managerCashMny) {
        this.managerCashMny = managerCashMny;
    }
    /**
     * 所属单位董事长审批兑现金额
     */
    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    /**
     * 所属单位董事长审批兑现金额
     */
    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }
    
}

==> ejc-zjkjcost-api-3.0.0-20221020.005734-60-sources.jar: com/ejianc/business/zjkjcost/finish/vo/ApproveVO.java <==
package com.ejianc.business.zjkjcost.finish.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 竣工考核-目标责任书竣工兑现审批-主表
 * 
 * @author generator
 * 
 */
@ApiModel("竣工考核-目标责任书竣工兑现审批-主表")
public class ApproveVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("单据编号")
    private String billCode;
    @ApiModelProperty("申报主表id")
    private Long applyId;
    @ApiModelProperty("申报主表code")
    private Long applyCode;
    @ApiModelProperty("合同主键")
    private Long contractId;
    @ApiModelProperty("合同名称")
    private String contractName;
    @ApiModelProperty("合同code")
    private String contractCode;
    @ApiModelProperty("项目")
    private Long projectId;
    @ApiModelProperty("项目名称")
    private String projectName;
    @ApiModelProperty("项目code")
    private String projectCode;
    @ApiModelProperty("经办人")
    private Long employeeId;
    @ApiModelProperty("经办人名称")
    private String employeeName;
    @ApiModelProperty("经办部门")
    private Long departmentId;
    @ApiModelProperty("经办部门名称")
    private String departmentName;
    @ApiModelProperty("组织")
    private Long orgId;
    @ApiModelProperty("组织名称")
    private String orgName;
    @ApiModelProperty("组织code")
    private String orgCode;
    @ApiModelProperty("父级组织名称")
    private String parentOrgName;
    @ApiModelProperty("父级组织编码")
    private String parentOrgCode;
    @ApiModelProperty("父级组织")
    private Long parentOrgId;
    @ApiModelProperty("依据")
    private String accord;
    @ApiModelProperty("所属单位商务管理部意见兑现金额")
    private BigDecimal departmentCashMny;
    @ApiModelProperty("所属单位财务资金部扣款金额")
    private BigDecimal capitalDeductMny;
    @ApiModelProperty("所属单位建造管理部扣款金额")
    private BigDecimal buildDeductMny;
    @ApiModelProperty("所属单位工程技术中心扣款金额")
    private BigDecimal technologyDeductMny;
    @ApiModelProperty("所属单位设计中心扣款金额")
    private BigDecimal designDeductMny;
    @ApiModelProperty("所属单位分管领导审核兑现金额")
    private BigDecimal leaderCashMny;
    @ApiModelProperty(" 所属单位总经理审批兑现金额")
    private BigDecimal managerCashMny;
    @ApiModelProperty("所属单位董事长审批兑现金额")
    private BigDecimal chairmanCashMny;

    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @ApiModelProperty("单据状态（审批必须字段）")
    private String billStateName;

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 申报主表id
     */
    public Long getApplyId() {
        return applyId;
    }

    /**
     * 申报主表id
     */
    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    /**
     * 申报主表code
     */
    public Long getApplyCode() {
        return applyCode;
    }

    /**
     * 申报主表code
     */
    public void setApplyCode(Long applyCode) {
        this.applyCode = applyCode;
    }
    /**
     * 合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同code
     */
    public String getContractCode() {
        return contractCode;
    }

    /**
     * 合同code
     */
    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 项目
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目code
     */
    public String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目code
     */
    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 经办部门
     */
    public Long getDepartmentId() {
        return departmentId;
    }

    /**
     * 经办部门
     */
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    /**
     * 经办部门名称
     */
    public String getDepartmentName() {
        return departmentName;
    }

    /**
     * 经办部门名称
     */
    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 组织code
     */
    public String getOrgCode() {
        return orgCode;
    }

    /**
     * 组织code
     */
    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    /**
     * 父级组织名称
     */
    public String getParentOrgName() {
        return parentOrgName;
    }

    /**
     * 父级组织名称
     */
    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    /**
     * 父级组织编码
     */
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    /**
     * 父级组织编码
     */
    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    /**
     * 父级组织
     */
    public Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 父级组织
     */
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 依据
     */
    public String getAccord() {
        return accord;
    }

    /**
     * 依据
     */
    public void setAccord(String accord) {
        this.accord = accord;
    }
    /**
     * 所属单位商务管理部意见兑现金额
     */
    public BigDecimal getDepartmentCashMny() {
        return departmentCashMny;
    }

    /**
     * 所属单位商务管理部意见兑现金额
     */
    public void setDepartmentCashMny(BigDecimal departmentCashMny) {
        this.departmentCashMny = departmentCashMny;
    }
    /**
     * 所属单位财务资金部扣款金额
     */
    public BigDecimal getCapitalDeductMny() {
        return capitalDeductMny;
    }

    /**
     * 所属单位财务资金部扣款金额
     */
    public void setCapitalDeductMny(BigDecimal capitalDeductMny) {
        this.capitalDeductMny = capitalDeductMny;
    }
    /**
     * 所属单位建造管理部扣款金额
     */
    public BigDecimal getBuildDeductMny() {
        return buildDeductMny;
    }

    /**
     * 所属单位建造管理部扣款金额
     */
    public void setBuildDeductMny(BigDecimal buildDeductMny) {
        this.buildDeductMny = buildDeductMny;
    }
    /**
     * 所属单位工程技术中心扣款金额
     */
    public BigDecimal getTechnologyDeductMny() {
        return technologyDeductMny;
    }

    /**
     * 所属单位工程技术中心扣款金额
     */
    public void setTechnologyDeductMny(BigDecimal technologyDeductMny) {
        this.technologyDeductMny = technologyDeductMny;
    }
    /**
     * 所属单位设计中心扣款金额
     */
    public BigDecimal getDesignDeductMny() {
        return designDeductMny;
    }

    /**
     * 所属单位设计中心扣款金额
     */
    public void setDesignDeductMny(BigDecimal designDeductMny) {
        this.designDeductMny = designDeductMny;
    }
    /**
     * 所属单位分管领导审核兑现金额
     */
    public BigDecimal getLeaderCashMny() {
        return leaderCashMny;
    }

    /**
     * 所属单位分管领导审核兑现金额
     */
    public void setLeaderCashMny(BigDecimal leaderCashMny) {
        this.leaderCashMny = leaderCashMny;
    }
    /**
     *  所属单位总经理审批兑现金额
     */
    public BigDecimal getManagerCashMny() {
        return managerCashMny;
    }

    /**
     *  所属单位总经理审批兑现金额
     */
    public void setManagerCashMny(BigDecimal managerCashMny) {
        this.managerCashMny = managerCashMny;
    }
    /**
     * 所属单位董事长审批兑现金额
     */
    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    /**
     * 所属单位董事长审批兑现金额
     */
    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }
    /**
     * 合同主键
     */
    @ReferSerialTransfer(referCode = "ejc-zjkj-incontract")
    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
}
